==> cl-local-time-20240817_0.any_any.noarch.tbz2: opt/local/share/common-lisp/source/cl-local-time/src/package.lisp <==
(defpackage #:local-time
  (:use #:cl)
  (:export #:timestamp
           #:date
           #:time-of-day
           #:make-timestamp
           #:clone-timestamp
           #:day-of
           #:sec-of
           #:nsec-of
           #:timestamp<
           #:timestamp<=
           #:timestamp>
           #:timestamp>=
           #:timestamp=
           #:timestamp/=
           #:timestamp-maximum
           #:timestamp-minimum
           #:adjust-timestamp
           #:adjust-timestamp!
           #:timestamp-whole-year-difference
           #:days-in-month
           #:timestamp-
           #:timestamp+
           #:timestamp-difference
           #:timestamp-minimize-part
           #:timestamp-maximize-part
           #:with-decoded-timestamp
           #:decode-timestamp
           #:timestamp-century
           #:timestamp-day
           #:timestamp-day-of-week
           #:timestamp-decade
           #:timestamp-hour
           #:timestamp-microsecond
           #:timestamp-millennium
           #:timestamp-millisecond
           #:timestamp-minute
           #:timestamp-month
           #:timestamp-second
           #:timestamp-week
           #:timestamp-year
           #:parse-timestring
           #:invalid-timestring
           #:format-timestring
           #:format-rfc1123-timestring
           #:to-rfc1123-timestring
           #:format-rfc3339-timestring
           #:to-rfc3339-timestring
           #:encode-timestamp
           #:parse-rfc3339-timestring
           #:universal-to-timestamp
           #:timestamp-to-universal
           #:unix-to-timestamp
           #:timestamp-to-unix
           #:timestamp-subtimezone
           #:define-timezone
           #:*default-timezone*
           #:*clock*
           #:leap-second-adjusted
           #:clock-now
           #:clock-today
           #:find-timezone-by-location-name
           #:timezones-matching-subzone
           #:all-timezones-matching-subzone
           #:reread-timezone-repository
           #:now
           #:today
           #:enable-read-macros
           #:+utc-zone+
           #:+gmt-zone+
           #:+month-names+
           #:+short-month-names+
           #:+day-names+
           #:+short-day-names+
           #:+seconds-per-day+
           #:+seconds-per-hour+
           #:+seconds-per-minute+
           #:+minutes-per-day+
           #:+minutes-per-hour+
           #:+hours-per-day+
           #:+days-per-week+
           #:+months-per-year+
           #:+iso-8601-format+
           #:+iso-8601-date-format+
           #:+iso-8601-time-format+
           #:+rfc3339-format+
           #:+rfc3339-format/date-only+
           #:+asctime-format+
           #:+rfc-1123-format+
           #:+iso-week-date-format+
           #:astronomical-julian-date
           #:modified-julian-date
           #:astronomical-modified-julian-date
           #:zone-name
           #:encode-universal-time-with-tz
           #:decode-universal-time-with-tz))

==> cl-local-time-20250131_0.any_any.noarch.tbz2: opt/local/share/common-lisp/source/cl-local-time/src/package.lisp <==
(defpackage #:local-time
  (:use #:cl)
  (:export #:timestamp
           #:date
           #:time-of-day
           #:make-timestamp
           #:clone-timestamp
           #:day-of
           #:sec-of
           #:nsec-of
           #:timestamp<
           #:timestamp<=
           #:timestamp>
           #:timestamp>=
           #:timestamp=
           #:timestamp/=
           #:timestamp-maximum
           #:timestamp-minimum
           #:adjust-timestamp
           #:adjust-timestamp!
           #:timestamp-whole-year-difference
           #:days-in-month
           #:timestamp-
           #:timestamp+
           #:timestamp-difference
           #:timestamp-minimize-part
           #:timestamp-maximize-part
           #:with-decoded-timestamp
           #:decode-timestamp
           #:timestamp-century
           #:timestamp-day
           #:timestamp-day-of-week
           #:timestamp-decade
           #:timestamp-hour
           #:timestamp-microsecond
           #:timestamp-millennium
           #:timestamp-millisecond
           #:timestamp-minute
           #:timestamp-month
           #:timestamp-second
           #:timestamp-week
           #:timestamp-year
           #:parse-timestring
           #:invalid-timestring
           #:format-timestring
           #:format-rfc1123-timestring
           #:to-rfc1123-timestring
           #:format-rfc3339-timestring
           #:to-rfc3339-timestring
           #:encode-timestamp
           #:parse-rfc3339-timestring
           #:universal-to-timestamp
           #:timestamp-to-universal
           #:unix-to-timestamp
           #:timestamp-to-unix
           #:timestamp-subtimezone
           #:define-timezone
           #:*default-timezone*
           #:*clock*
           #:leap-second-adjusted
           #:clock-now
           #:clock-today
           #:find-timezone-by-location-name
           #:timezones-matching-subzone
           #:all-timezones-matching-subzone
           #:reread-timezone-repository
           #:now
           #:today
           #:enable-read-macros
           #:+utc-zone+
           #:+gmt-zone+
           #:+month-names+
           #:+short-month-names+
           #:+day-names+
           #:+short-day-names+
           #:+seconds-per-day+
           #:+seconds-per-hour+
           #:+seconds-per-minute+
           #:+minutes-per-day+
           #:+minutes-per-hour+
           #:+hours-per-day+
           #:+days-per-week+
           #:+months-per-year+
           #:+iso-8601-format+
           #:+iso-8601-date-format+
           #:+iso-8601-time-format+
           #:+rfc3339-format+
           #:+rfc3339-format/date-only+
           #:+asctime-format+
           #:+rfc-1123-format+
           #:+iso-week-date-format+
           #:astronomical-julian-date
           #:modified-julian-date
           #:astronomical-modified-julian-date
           #:zone-name
           #:encode-universal-time-with-tz
           #:decode-universal-time-with-tz
           #:sunday?
           #:monday?
           #:tuesday?
           #:wednesday?
           #:thursday?
           #:friday?
           #:saturday?))
